Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(684)

Unified Diff: components/offline_pages/background/request_coordinator_event_logger.h

Issue 2324493005: [Offline Pages] Adds event logs for requests dropped due to number of start or complete attempts. (Closed)
Patch Set: Addresses dimich feedback Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/background/request_coordinator_event_logger.h
diff --git a/components/offline_pages/background/request_coordinator_event_logger.h b/components/offline_pages/background/request_coordinator_event_logger.h
index 4ac05e89274d108644886a1172b830994bdef7ad..61a7beb94593c29fb6c46308471355e67dc7bb93 100644
--- a/components/offline_pages/background/request_coordinator_event_logger.h
+++ b/components/offline_pages/background/request_coordinator_event_logger.h
@@ -9,6 +9,7 @@
#include <string>
#include "components/offline_pages/background/offliner.h"
+#include "components/offline_pages/background/request_notifier.h"
#include "components/offline_pages/background/request_queue.h"
#include "components/offline_pages/offline_event_logger.h"
@@ -16,11 +17,17 @@ namespace offline_pages {
class RequestCoordinatorEventLogger : public OfflineEventLogger {
public:
- // Records that a background task with SavePageRequest |request_id|
- // has been updated.
- void RecordSavePageRequestUpdated(const std::string& name_space,
- Offliner::RequestStatus new_status,
- int64_t request_id);
+ // Records the result of a background task attempt for SavePageRequest
+ // |request_id|.
+ void RecordOfflinerResult(const std::string& name_space,
+ Offliner::RequestStatus new_status,
+ int64_t request_id);
+
+ // Records the reason for dropped SavePageRequest |request_id|.
+ void RecordDroppedSavePageRequest(
+ const std::string& name_space,
+ RequestNotifier::BackgroundSavePageResult result,
+ int64_t request_id);
void RecordUpdateRequestFailed(const std::string& name_space,
RequestQueue::UpdateRequestResult result);

Powered by Google App Engine
This is Rietveld 408576698